{%- set favicon_url = favicon_url or ('_static/' + ('images/favicon.svg')) %} {%
extends "sphinx_book_theme/layout.html" %} {%- block content %}
<!-- Google Tag Manager (noscript) -->
<noscript
  ><iframe
    src="https://www.googletagmanager.com/ns.html?id={{ theme_google_tag_manager_id }}"
    height="0"
    width="0"
    style="display: none; visibility: hidden"
  ></iframe
></noscript>
<!-- End Google Tag Manager (noscript) -->

<nav class="dask-nav container-fluid">
  <ul>
    <li class="logo">
      <a href="https://docs.dask.org/">
        <img
          class="caption"
          src="{{ pathto('_static/images/dask-horizontal-white.svg', 1) }}"
        />
      </a>
    </li>

    <li>
      <a href="https://docs.dask.org/">Dask</a>
    </li>

    <li>
      <a href="https://distributed.dask.org/">Distributed</a>
    </li>

    <li>
      <a href="https://ml.dask.org/">Dask ML</a>
    </li>

    <li>
      <a href="https://examples.dask.org/">Examples</a>
    </li>

    <li>
      <a href="https://docs.dask.org/en/latest/ecosystem.html">Ecosystem</a>
    </li>

    <li>
      <a href="https://docs.dask.org/en/latest/support.html">Community</a>
    </li>
  </ul>
</nav>

{{ super() }} {%- endblock %} {% block footer %}
<!-- Google Tag Manager -->
<script>
  (function (w, d, s, l, i) {
    w[l] = w[l] || [];
    w[l].push({
      "gtm.start": new Date().getTime(),
      event: "gtm.js",
    });
    var f = d.getElementsByTagName(s)[0],
      j = d.createElement(s),
      dl = l != "dataLayer" ? "&l=" + l : "";
    j.async = true;
    j.src = "https://www.googletagmanager.com/gtm.js?id=" + i + dl;
    f.parentNode.insertBefore(j, f);
  })(
    window,
    document,
    "script",
    "dataLayer",
    "{{ theme_google_tag_manager_id }}"
  );
</script>
<!-- End Google Tag Manager -->

{{ super() }} {%- endblock %}
